@@ -97,11 +97,13 @@ sub new {
 
 		# unused APT vars
 		'apt::cache-limit' => undef,
+		'apt::get::build-dep-automatic' => 1,
 		'apt::get::show-upgraded' => 0,
 		'acquire::pdiffs' => 1,
 
 		# Cupt vars
 		'acquire::http::allow-redirects' => 1,
+		'cupt::cache::obey-hold' => 1000000,
 		'cupt::console::allow-untrusted' => 0,
 		'cupt::console::assume-yes' => 0,
 		'cupt::directory::state' => 'var/lib/cupt',
@@ -174,6 +176,7 @@ sub new {
 		'aptlistbugs::*',
 		'unattended-upgrade::*',
 		'aptitude::*',
+		'dselect::*',
 
 		# used Cupt vars
 		'cupt::downloader::protocols::*::priority',
@@ -205,9 +208,19 @@ sub new {
 		'cupt::downloader::protocols::http::methods' => [ 'curl' ],
 		'cupt::downloader::protocols::ftp::methods' => [ 'curl' ],
 		'cupt::resolver::synchronize-source-versions::exceptions' => ['db', 'linux-\d.\d'],
-		'cupt::worker::allow-indirect-upgrade' => [ 'libc6-i686' ], # hack to
-				# work around packages with strict unkeepable Pre-Depends and ability to
-				# damage the system when dependencies is not satisfied
+		# hack to work around packages with strict unkeepable
+		# Pre-Depends and ability to damage the system when
+		# dependencies is not satisfied
+		'cupt::worker::allow-indirect-upgrade' => [
+			'libc6-i686',
+			'openjdk-6-jre',
+			'openjdk-6-jre-lib',
+			'openjdk-6-jre-headless',
+			'openoffice.org-core',
+			'openoffice.org-common',
+			'openoffice.org-writer2latex',
+			'openoffice.org-java-common',
+		],
 	};
 
 	$self->set_scalar('apt::architecture', $self->_get_architecture());
@@ -344,7 +357,7 @@ sub get_list { ## no critic (RequireFinalReturn)
 	if (defined $self->_list_vars->{$option_name}) {
 		return @{$self->_list_vars->{$option_name}};
 	} elsif ($self->_is_optional_option($option_name)) {
-		return undef;
+		return ();
 	} else {
 		mydie("an attempt to get wrong list option '%s'", $option_name);
 	}
