@@ -176,10 +176,13 @@ sub get_acquire_suboption_for_uri ($$$) {
 	my $protocol = $uri_object->scheme();
 	my $host = $uri_object->host();
 	# this "zoo" of per-host variants is given by APT...
-	my $proxy = $config->get_string("acquire::${protocol}::${suboption_name}::${host}") //
+	my $result = $config->get_string("acquire::${protocol}::${suboption_name}::${host}") //
 			$config->get_string("acquire::${protocol}::${host}::${suboption_name}") //
 			$config->get_string("acquire::${protocol}::${suboption_name}");
-	return $proxy;
+	if ($suboption_name eq 'proxy' && defined $result && $result eq 'DIRECT') {
+		$result = '';
+	}
+	return $result;
 }
 
 1;
